.. AUTO-GENERATED FILE -- DO NOT EDIT!

bart.tree
=========

Module: :mod:`bart.tree`
------------------------
Inheritance diagram for ``ISLP.bart.tree``:

.. inheritance-diagram:: ISLP.bart.tree 
   :parts: 3

.. automodule:: ISLP.bart.tree

.. currentmodule:: ISLP.bart.tree

Classes
-------

:class:`BaseNode`
~~~~~~~~~~~~~~~~~


.. autoclass:: BaseNode
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__

:class:`LeafNode`
~~~~~~~~~~~~~~~~~


.. autoclass:: LeafNode
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__

:class:`SplitNode`
~~~~~~~~~~~~~~~~~~


.. autoclass:: SplitNode
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__

:class:`Tree`
~~~~~~~~~~~~~


.. autoclass:: Tree
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__
